<!--- Top of README Badges (automated) --->
[![PyPI](https://img.shields.io/pypi/v/icecube-skywriter)](https://pypi.org/project/icecube-skywriter/) [![GitHub release (latest by date including pre-releases)](https://img.shields.io/github/v/release/icecube/skywriter?include_prereleases)](https://github.com/icecube/skywriter/) [![PyPI - License](https://img.shields.io/pypi/l/icecube-skywriter)](https://github.com/icecube/skywriter/blob/main/LICENSE) [![Lines of code](https://img.shields.io/tokei/lines/github/icecube/skywriter)](https://github.com/icecube/skywriter/) [![GitHub issues](https://img.shields.io/github/issues/icecube/skywriter)](https://github.com/icecube/skywriter/issues?q=is%3Aissue+sort%3Aupdated-desc+is%3Aopen) [![GitHub pull requests](https://img.shields.io/github/issues-pr/icecube/skywriter)](https://github.com/icecube/skywriter/pulls?q=is%3Apr+sort%3Aupdated-desc+is%3Aopen) 
<!--- End of README Badges (automated) --->
# skywriter
Upstream Tools for SkyDriver &amp; the Skymap Scanner
